/*
 * Copyright (C) 2011 Atmark Techno, Inc. All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <linux/platform_device.h>

#include <asm/mach-types.h>
#include <asm/mach/arch.h>
#include <asm/mach/time.h>
#include <mach/common.h>
#include <mach/mx25.h>
#include <mach/iomux.h>
#include <mach/imx-uart.h>

extern void armadillo400_watchdog_init(void);
extern void armadillo400_uart_init(void);
extern void armadillo400_mtd_init(void) __attribute__((weak));
extern void armadillo400_i2c_init(void);
extern void armadillo400_sdhc_init(void) __attribute__((weak));
extern void armadillo400_fec_init(void);
extern void armadillo400_fb_init(void) __attribute__((weak));
extern void armadillo400_pwm_init(void);
extern void armadillo400_touchscreen_init(void) __attribute__((weak));
extern void armadillo400_key_init(void);
extern void armadillo400_led_init(void);
extern void armadillo400_gpio_init(void);
extern void armadillo400_usb_init(void);
extern void armadillo400_audio_init(void) __attribute__((weak));

static void __init armadillo400_init(void)
{
	armadillo400_watchdog_init();
	armadillo400_uart_init();
	armadillo400_mtd_init();
	armadillo400_i2c_init();
	armadillo400_sdhc_init();
	armadillo400_fec_init();
	armadillo400_pwm_init();
	armadillo400_key_init();
	armadillo400_led_init();
	armadillo400_gpio_init();
	armadillo400_usb_init();
	armadillo400_audio_init();
}

static void __init armadillo420_init(void)
{
	armadillo400_init();
}

static void __init armadillo440_init(void)
{
	armadillo400_init();

	armadillo400_fb_init();
	armadillo400_touchscreen_init();
}

static void __init armadillo400_timer_init(void)
{
	mx25_clocks_init();
}

static struct sys_timer armadillo400_timer = {
	.init   = armadillo400_timer_init,
};

#if defined(CONFIG_MACH_ARMADILLO420)
MACHINE_START(ARMADILLO420, "Armadillo-420")
	/* Maintainer: Atmark Techno, Inc. */
	.phys_io	= MX25_AIPS1_BASE_ADDR,
	.io_pg_offst	= ((MX25_AIPS1_BASE_ADDR_VIRT) >> 18) & 0xfffc,
	.boot_params	= PHYS_OFFSET + 0x100,
	.map_io		= mx25_map_io,
	.init_irq	= mx25_init_irq,
	.init_machine	= armadillo420_init,
	.timer		= &armadillo400_timer,
MACHINE_END
#endif

#if defined(CONFIG_MACH_ARMADILLO440)
MACHINE_START(ARMADILLO440, "Armadillo-440")
	/* Maintainer: Atmark Techno, Inc. */
	.phys_io	= MX25_AIPS1_BASE_ADDR,
	.io_pg_offst	= ((MX25_AIPS1_BASE_ADDR_VIRT) >> 18) & 0xfffc,
	.boot_params	= PHYS_OFFSET + 0x100,
	.map_io		= mx25_map_io,
	.init_irq	= mx25_init_irq,
	.init_machine	= armadillo440_init,
	.timer		= &armadillo400_timer,
MACHINE_END
#endif
